Learn R Programming

kiwisR (version 0.2.4)

ki_group_list: Get list of available groups

Description

Returns a tibble containing metadata available groups. This can be used to further filter down other queries like `ki_station_list`.

Usage

ki_group_list(hub, datasource = 0)

Value

A tibble with three columns: group_id, group_name and group_type.

Arguments

hub

The KiWIS database you are querying. Either one of the defaults or a URL. See README.

datasource

(Optional) The data source to be used, defaults to 0.

Examples

Run this code
if (FALSE) {
ki_group_list(hub = "swmc")
}

Run the code above in your browser using DataLab