A tibble containing all available time series for selected stations.
Arguments
hub
The KiWIS database you are querying. Either one of the defaults or a URL.
See README.
station_id
Either a single station id or a vector of station ids. Can be string or numeric.
Station ids can be found using the ki_station_list function.
ts_name
(Optional) A specific time series short name to search for. Supports the use of "*" as a wildcard.
coverage
(Optional) Whether or not to return period of record columns.
Defaults to TRUE, change to FALSE for faster queries.
group_id
(Optional) A time series group id (see ki_group_list).
return_fields
(Optional) Specific fields to return. Consult your KiWIS hub services documentation for available options.
Should be a comma separate string or a vector.
datasource
(Optional) The data source to be used, defaults to 0.