powered by
Returns a tibble containing metadata available groups. This can be used to further filter down other queries like `ki_station_list`.
ki_group_list(hub, datasource = 0)
A tibble with three columns: group_id, group_name and group_type.
The KiWIS database you are querying. Either one of the defaults or a URL. See README.
(Optional) The data source to be used, defaults to 0.
if (FALSE) { ki_group_list(hub = "swmc") }
Run the code above in your browser using DataLab