A tibble with following columns by default: Timestamp, Value, ts_name, Units, station_name
Arguments
hub
The KiWIS database you are querying. Either one of the defaults or a URL.
See README.
ts_id
Either: a single time series id or a vector of time series ids.
Time series ids can be found using the `ki_timeseries_list` function.
start_date
A date string formatted "YYYY-MM-DD". Defaults to yesterday.
end_date
A date string formatted "YYYY-MM-DD". Defaults to today.
return_fields
(Optional) Specific fields to return. Consult your KiWIS hub services documentation for available options.
Should be a comma separate string or a vector.
datasource
(Optional) The data source to be used, defaults to 0.